﻿// <copyright file="Program.cs" company="ANUJ Technologies Inc.">
// Copyright (c) 10-13-2011 All Right Reserved
// </copyright>
// <author>Anuj Varma, www.anujvarma.com</author>
// <date>10-13-2011</date>
// <summary>Class representing a Program.cs entity.</summary>

using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;

namespace SimpleLINQPerformance
{
    class Program
    {
        const int SIZE = 200000, iterations = 100;
        
        static void Main(string[] args)
        {
            LinqQuery();
            ForLoop();
        }

        static int[] CreateData()
        {
           int[] myArray = new int[SIZE];
           for (int i = 0; i < SIZE; i++)
               myArray[i] = i;

           return myArray;
        }

        static void LinqQuery()
        {
            DateTime start = DateTime.Now;
            int[] data = CreateData();
            IEnumerable<int> searchResults = null;
            for (int i = 0; i <= iterations; i++)
            {
                searchResults = (from num in data where num < 100 select num);  
            }

            int count  = searchResults.Count();
                        
            TimeSpan totalTime = DateTime.Now - start;
            Console.WriteLine("Total Time LinqQuery = " + totalTime.Milliseconds + " ms");
        }

        static void ForLoop()
        {
            IList<int> searchResults = new List<int>();
            DateTime start = DateTime.Now;
            int[] data = CreateData();
            
            for (int i = 0; i <= iterations; i++)
            {
                foreach (int j in data)
                {
                    if (j < 100)
                        searchResults.Add(j); 
                }
            }

            TimeSpan totalTime = DateTime.Now - start;
            Console.WriteLine("Total Time For Loop = " + totalTime.Milliseconds + " ms");
        }

    }
}
